@@ -1,11 +1,11 @@
-import typing
+from . import types
 
 
 def raise_exception(
-    exception_class: typing.Type[Exception],
-    *args: typing.Any,
-    **kwargs: typing.Any,
-) -> typing.Callable:
+    exception_class: types.Type[Exception],
+    *args: types.Any,
+    **kwargs: types.Any,
+) -> types.Callable[..., None]:
     '''
     Returns a function that raises an exception of the given type with the
     given arguments.
@@ -16,11 +16,11 @@ def raise_exception(
     ValueError: spam
     '''
 
-    def raise_(*args_: typing.Any, **kwargs_: typing.Any) -> typing.Any:
+    def raise_(*args_: types.Any, **kwargs_: types.Any) -> types.Any:
         raise exception_class(*args, **kwargs)
 
     return raise_
 
 
-def reraise(*args: typing.Any, **kwargs: typing.Any) -> typing.Any:
+def reraise(*args: types.Any, **kwargs: types.Any) -> types.Any:
     raise
